pub enum AstroError {
InvalidCoordinate {
coord_type: &'static str,
value: f64,
valid_range: &'static str,
},
InvalidDateTime {
reason: String,
},
CalculationError {
calculation: &'static str,
reason: String,
},
NeverRisesOrSets {
always_above: bool,
},
InvalidDmsFormat {
input: String,
expected: &'static str,
},
OutOfRange {
parameter: &'static str,
value: f64,
min: f64,
max: f64,
},
ProjectionError {
reason: String,
},
}Expand description
Main error type for astro-math operations.
This enum represents all possible errors that can occur during astronomical calculations. Each variant provides specific information about what went wrong.
Variants
InvalidCoordinate
Invalid coordinate value
Fields
InvalidDateTime
Invalid time/date
CalculationError
Calculation failed
NeverRisesOrSets
Object never rises or sets
InvalidDmsFormat
Invalid DMS string format
OutOfRange
Value out of valid range
Fields
ProjectionError
Projection error (e.g., point on opposite side of sky)